/*
 * Copyright (C) 1996  Warren Jasper
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/*
 * d2ac.h
 */

/*#define DAC_BASE     0x340     */  /* Default base address */

/* Default device major number */
#ifndef DEFAULT_MAJOR_DEV
#define DEFAULT_MAJOR_DEV  33    /* Default Major Device Number */
#endif
#define DA_CHANNELS         6    /* 6 Digital to Analog Channels */
#define DIO_PORTS           3    /* 24 Digital I/O Ports (3 bytes) */

#define PORT_MIN         0x300   /* minimum base address used in autodetecting */
#define PORT_MAX         0x3e0   /* maximum base address allowed by board      */
#define PORT_STEP        0x10    /* base step ( 16 bytes)                      */
#define PORT_SIZE        0x10    /* uses 16 bytes of registers                 */

/* I/O Register locations */

/* NOTE: base_reg to be found dynamically at boot time. Not hard coded into driver */

#define CHAN0_LSB         (base_reg)     /* D/A 0 Least Significant Byte */
#define CHAN0_MSB         (base_reg+1)   /* D/A 0 Most Significant Byte */
#define CHAN1_LSB         (base_reg+2)   /* D/A 1 Least Significant Byte */
#define CHAN1_MSB         (base_reg+3)   /* D/A 1 Most Significant Byte */
#define CHAN2_LSB         (base_reg+4)   /* D/A 2 Least Significant Byte */
#define CHAN2_MSB         (base_reg+5)   /* D/A 2 Most Significant Byte */
#define CHAN3_LSB         (base_reg+6)   /* D/A 3 Least Significant Byte */
#define CHAN3_MSB         (base_reg+7)   /* D/A 3 Most Significant Byte */
#define CHAN4_LSB         (base_reg+8)   /* D/A 4 Least Significant Byte */
#define CHAN4_MSB         (base_reg+9)   /* D/A 4 Most Significant Byte */
#define CHAN5_LSB         (base_reg+10)  /* D/A 5 Least Significant Byte */
#define CHAN5_MSB         (base_reg+11)  /* D/A 5 Most Significant Byte */

#define DIO_PORTA             (base_reg+12)  /* Port A 8 bit I/O of 8255 */
#define DIO_PORTB             (base_reg+13)  /* Port B 8 bit I/O of 8255 */
#define DIO_PORTC             (base_reg+14)  /* Port C 4+4 bit of 8255 */
#define DIO_CNTRL_REG         (base_reg+15)  /* Mode and Direction Control Register */

/* General defines */

#define TRUE  1
#define FALSE 0
#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long

/* 
#define DEBUG 
 */

/* Interrupt context data. Controls interrupt service handler */


/* Values kept for each channel. */

typedef struct CHANNEL_REC {
  int  open;            /* Is channel device open()         */
  WORD value;           /* value of D/A Channel             */
  WORD addr;            /* address of the channel           */
  int mode;             /* mode for 8255                    */
} ChanRec;

