/*
 * Copyright (C) 1996   Warren Jasper
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/***************************************************************************
 *
 *  dacwrite.c
 *
 *  This program is used to test the CIO-DDA06/16 Digital to Analog
 *  Linux loadable module(dac).
 *
 ***************************************************************************/

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include "dac.h"

#define BYTE unsigned char
#define WORD unsigned short
#define LONG unsigned long


/***************************************************************************
 *
 *  Global Data
 *
 ***************************************************************************/

char *DevName = "/dev/dac00";
char DevNameIO[20];
int  Count    = 1;
int  NoStop   = 0;
int  Print    = 1;
int  Mode     = 0;
int  Status;

/***************************************************************************
 *
 *  Show user how the command line is used.
 *
 ***************************************************************************/

void Usage( void )
{
    fprintf(stderr, "\n\
Usage: adcread \'options\'\n\
Options:\n\
              [-dev /dev/dac##]  - Specify device file.\n
              [-ct ##]           - Number of samples to write\n
              [-noprint]         - Don't print samples\n
              [-nostop]          - Write forever\n
\n");
    exit(1);
}

/***************************************************************************
 *
 *  Process command line switches
 *
 ***************************************************************************/

void DoCommandLine(int argc, char **argv)
{
int i;

i = 1;

while (i < argc) {
  if (strcmp(argv[i], "-dev") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      DevName = argv[i];
  } else if (strcmp(argv[i], "-ct") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      Count = atoi(argv[i]);
  } else if (strcmp(argv[i], "-noprint") == 0) {
    Print = 0;
  } else if (strcmp(argv[i], "-nostop") == 0) {
    NoStop = 1;
  } else {
    Usage();
  }
  i++;
}

}

/***************************************************************************
 *
 *  Main
 *
 ***************************************************************************/

int main(int argc, char **argv)
{
  int   i=0;
  int   fd;
  int fd_A, fd_B, fd_C;  /* file descriptors for dio Ports A, B, and C */
  BYTE  bReg;
  float x;
  WORD  value;

  double pi =  M_PI;

  DoCommandLine(argc, argv);
	
  /* Open the device file for the counter
   */

  printf("Running in mode %d\n", Mode);

  if ((fd = open(DevName, O_RDWR )) < 0) {
    perror(DevName);
    printf("error opening device %s\n", DevName);
    exit(2);
  }

  strcpy(DevNameIO, "/dev/dioA");
  if ((fd_A = open(DevNameIO, O_RDWR )) < 0) {
    perror("DevNameIO");
    printf("error opening device %s\n", DevNameIO);
    exit(2);
  }
  strcpy(DevNameIO, "/dev/dioB");
  if ((fd_B = open(DevNameIO, O_RDWR )) < 0) {
    perror(DevNameIO);
    printf("error opening device %s\n", DevNameIO);
    exit(2);
  }
  strcpy(DevNameIO, "/dev/dioC");
  if ((fd_C = open(DevNameIO, O_RDWR )) < 0) {
    perror(DevNameIO);
    printf("error opening device %s\n", DevNameIO);
    exit(2);
  }

  ioctl(fd_A, DIO_SET_DIRECTION, PORT_OUTPUT);
  ioctl(fd_B, DIO_SET_DIRECTION, PORT_OUTPUT);
  ioctl(fd_C, DIO_SET_DIRECTION, HIGH_PORT_OUTPUT);
  ioctl(fd_C, DIO_SET_DIRECTION, LOW_PORT_OUTPUT);

  /* Set voltage gain */

    do {
       x  = (sin(i*pi/128.) + 1)/2.*65535;
       value = (WORD) x;
       write(fd,&value,2);
       write(fd_A, &i, 1);
       write(fd_B, &i, 1);
       write(fd_C, &i, 1);
       read(fd_A, &bReg, 1);
       read(fd_B, &bReg, 1);
       read(fd_C, &bReg, 1);
       i++;
       i %= 256;
    
    if (Print) {
      	  printf("Sample %d = %d\n", i, value); 
          printf("Port A value = %d\n", bReg);
          printf("Port B value = %d\n", bReg);
          printf("Port C value = %d\n", bReg);
     }
  } while (NoStop);
  close(fd);
  return 0;
}
	
	



